*
* PSpice Model
* 
* 6N6P ( Russian military ) 
* 
*
* Model used: "Improved VT Models for SPICE Simulations,"
*              Norman Koren, Glass Audio 5/96.
*
* Plate parameters determined by computerized optimization
* using Matlab script "Tuparam.m" by Norman Koren
*
* Plate data from : soviet tube manual datasheets
*
* The reliability of the HF characteristics
* for this model is probably not very high.
*
* It is likely that that additional complexity will be required
*
* to better model the HF behavior including the inclusion of heater terminals
* in order to explicitly incorporate grid, plate, and cathode to heater
* capacitances.
*
* And don't forget to add parasitic capacitances of ~0.7 pF
* for adjacent pins and ~0.5 pF for others (see Koren's article) 
* as well as for the effects of a shield (if used).
*
* No guarantees of any kind are made regarding the accuracy or suitability
* of any part of this model.
*
* Use at your own risk.
*
* data entry by Zoran Dimovski
*
*
* Connections:
*
*                      Plate
*                      | Grid
*                      | | Cathode
*                      | | |
*
.SUBCKT 6N6P  1 2 3 ; P G C (Triode)
*
+ PARAMS:
*
+ MU=17.04
+ EX=1.648
+ KG1=949.4
+ KP=151.26
+ KVB=300.0
+ VCT=0.00
*
* russian manual  21-Nov-2011
*
+ RGI = 2000
*
* Ccg = 4.4P+0.7P=5.1P
* Cgp = 3.5P+0.7P=4.2P
* Ccp = 1.85P+0.7P=3.55P
*
+ Ccg = 5.1PP
+ Cgp = 4.2P
+ Ccp = 3.55P
*
E1	7 	0	VALUE={V(1,3)/KP*LOG(1+EXP(KP*(1/MU+V(2,3)/SQRT(KVB+V(1,3)*V(1,3)))))}
RE1	7	0	1G
G1	1	3	VALUE={(PWR(V(7),EX)+PWRS(V(7),EX))/(KG1)}	;	(2*KG1) ???
RCP	1	3	1G	; TO AVOID FLOATING NODES IN MU-FOLLOWER
C1	2	3	{CCG}	; CATHODE GRID
C2	2	1	{CGP}	; GRID-PLATE
C3	1	3	{CCP}	; CATHODE-PLATE
D3	5	3	DX	; FOR GRID CURRENT
R1	2	5	{RGI}	; FOR GRID CURRENT
*
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N)
*
.ENDS 6N6P
*


